PartialScan

Struct PartialScan 

pub struct PartialScan {
    pub frequency: f32,
    pub start_angle: f32,
    pub end_angle: f32,
    pub points: [Option<Point>; 8],
}
A single partial scan containing up to NUMBER_OF_POINTS_PER_MEASUREMENT valid points.

Represents the decoded and filtered data from one raw LiDAR packet. Invalid points, zero-quality returns, and flagged measurements are represented as None.

Fields

frequency: f32

Rotation frequency in Hz.

start_angle: f32

Start angle of the packet in degrees.

end_angle: f32

End angle of the packet in degrees.

points: [Option<Point>; 8]

Array of NUMBER_OF_POINTS_PER_MEASUREMENT points within this partial scan.